```
Usage: vcd gateway sub-allocate-ip remove [OPTIONS] <name>

Options:
  -e, --external-network <external network>
                                  external network connected to the gateway.
                                  [required]
  -i, --ip-range <old-ip-range>   IP ranges that needs to be removed.
                                  [required]
  -h, --help                      Show this message and exit.

```
